Lutin
=====

`island` is a generic source downloader and syncronizer is a FREE software tool.


.. image:: https://badge.fury.io/py/island.png
    :target: https://pypi.python.org/pypi/island

Release (master)
----------------

.. image:: https://travis-ci.org/HeeroYui/island.svg?branch=master
    :target: https://travis-ci.org/HeeroYui/island



Developement (dev)
------------------

.. image:: https://travis-ci.org/HeeroYui/island.svg?branch=dev
    :target: https://travis-ci.org/HeeroYui/island


Instructions
------------

This is a tool to download ```git``` source repositiry in a versatile worktree

island is under a FREE license that can be found in the LICENSE file.
Any contribution is more than welcome ;)

git repository
--------------

http://github.com/HeeroYui/island/

Documentation
-------------

http://HeeroYui.github.io/island/

Installation
------------

Requirements: ``Python >= 2.7`` and ``pip``

Just run:

  pip install island

Install pip on debian/ubuntu:

  sudo apt-get install pip

Install pip on ARCH-linux:

  sudo pacman -S pip

Install pip on MacOs:

  sudo easy_install pip


License (MPL v2.0)
---------------------

Copyright island Edouard DUPIN

Licensed under the Mozilla Public License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    https://www.mozilla.org/MPL/2.0/

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

